@@ -2,6 +2,8 @@
 # -*- coding: utf-8 -*-
 
 import datetime
+from pageone import PageOne
+from particle import Particle 
 
 import lauteur
 from siegfried import (
@@ -14,21 +16,6 @@ from util import (
   imgs_from_html, utc_now, logger
   )
 
-try:
-  from particle import Particle 
-except ImportError:
-  imported_particle = False
-else:
-  imported_particle = True
-
-try:
-  from pageone import PageOne
-except ImportError:
-  imported_pageone = False 
-else:
-  imported_pageone = True
-
-
 try:
   import gevent
   from gevent.pool import Pool
@@ -92,18 +79,6 @@ class SupeRSS:
     self.num_workers = kwargs.get('num_workers', 20)
     self.is_full_text = kwargs.get('is_full_text', True)
 
-    # if we haven't import particle, assume we have the full text
-    if self.is_full_text and not imported_particle:
-      logger.warn('SupeRSS requires particle to get extract articles')
-      self.is_full_text = False
-
-    if self.homepage:
-      if not imported_particle or not imported_pageone:
-        raise SupeRSSInitError(
-          'SupeRSS requires particle and pageone installed '
-          'to parse a build a feed from a homepage.'
-          )
-
   def get_candidates(self, obj, jsonpath):
     """
     evaluate an object with jsonpath, 
@@ -172,7 +147,7 @@ class SupeRSS:
 
   def get_tags(self, entry):
     tags = self.get_candidates(entry, TAG_CANDIDATE_JSONPATH)
-    return list(set(tags))
+    return list(set([t for t in tags if t!= ""]))
 
 
   def get_url(self, entry):
@@ -302,8 +277,8 @@ class SupeRSS:
 
   def run_homepage(self):
     pg1 = PageOne(url=self.homepage)
-    p = Particle()
-    return self.run_concurrent(p.extract, pg1.articles())
+    pt = Particle()
+    return self.run_concurrent(pt.extract, pg1.articles())
 
   def run(self):
     """
